package com.ruoyi.web.controller.qdtl;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.qdtl.domain.TlElectricCarMileage;
import com.ruoyi.qdtl.service.ITlElectricCarMileageService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 电动车里程统计（每日）Controller
 *
 * @author ruoyi
 * @date 2022-07-04
 */
@RestController
@RequestMapping("/qdtl/mileage")
public class TlElectricCarMileageController extends BaseController {
    @Autowired
    private ITlElectricCarMileageService tlElectricCarMileageService;

    /**
     * 查询电动车里程统计（每日）列表
     */
    @PreAuthorize("@ss.hasPermi('qdtl:mileage:list')")
    @GetMapping("/list")
    public TableDataInfo list(TlElectricCarMileage tlElectricCarMileage) {
        startPage();
        List<TlElectricCarMileage> list = tlElectricCarMileageService.selectTlElectricCarMileageList(tlElectricCarMileage);
        return getDataTable(list);
    }

    /**
     * 导出电动车里程统计（每日）列表
     */
    @PreAuthorize("@ss.hasPermi('qdtl:mileage:export')")
    @Log(title = "电动车里程统计（每日）", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TlElectricCarMileage tlElectricCarMileage) {
        List<TlElectricCarMileage> list = tlElectricCarMileageService.selectTlElectricCarMileageList(tlElectricCarMileage);
        ExcelUtil<TlElectricCarMileage> util = new ExcelUtil<TlElectricCarMileage>(TlElectricCarMileage.class);
        util.exportExcel(response, list, "电动车里程统计（每日）数据");
    }

    /**
     * 获取电动车里程统计（每日）详细信息
     */
    @PreAuthorize("@ss.hasPermi('qdtl:mileage:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(tlElectricCarMileageService.selectTlElectricCarMileageById(id));
    }

    /**
     * 新增电动车里程统计（每日）
     */
    @PreAuthorize("@ss.hasPermi('qdtl:mileage:add')")
    @Log(title = "电动车里程统计（每日）", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TlElectricCarMileage tlElectricCarMileage) {
        return toAjax(tlElectricCarMileageService.insertTlElectricCarMileage(tlElectricCarMileage));
    }

    /**
     * 修改电动车里程统计（每日）
     */
    @PreAuthorize("@ss.hasPermi('qdtl:mileage:edit')")
    @Log(title = "电动车里程统计（每日）", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TlElectricCarMileage tlElectricCarMileage) {
        return toAjax(tlElectricCarMileageService.updateTlElectricCarMileage(tlElectricCarMileage));
    }

    /**
     * 删除电动车里程统计（每日）
     */
    @PreAuthorize("@ss.hasPermi('qdtl:mileage:remove')")
    @Log(title = "电动车里程统计（每日）", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tlElectricCarMileageService.deleteTlElectricCarMileageByIds(ids));
    }
}
