package com.ruoyi.web.controller.qdtl;

import cn.hutool.core.util.StrUtil;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.qdtl.domain.TlInspectionLocationLog;
import com.ruoyi.qdtl.service.ITlInspectionLocationLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 巡检记录管理Controller
 *
 * @author ruoyi
 * @date 2022-03-10
 */
@RestController
@RequestMapping("/qdtl/log")
public class TlInspectionLocationLogController extends BaseController {
    @Autowired
    private ITlInspectionLocationLogService tlInspectionLocationLogService;

    /**
     * 查询巡检记录管理列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TlInspectionLocationLog tlInspectionLocationLog) {
        startPage();
        if (StrUtil.isNotBlank(tlInspectionLocationLog.getAreaId())) {
            tlInspectionLocationLog.setAreaIds(StrUtil.split(tlInspectionLocationLog.getAreaId(), ','));
            tlInspectionLocationLog.setAreaId("");
        }
        List<TlInspectionLocationLog> list = tlInspectionLocationLogService.selectTlInspectionLocationLogList(tlInspectionLocationLog);
        return getDataTable(list);
    }

    /**
     * 巡检轨迹
     *
     * @param tlInspectionLocationLog
     * @return
     */
    @GetMapping("/trail/list")
    public AjaxResult trailList(TlInspectionLocationLog tlInspectionLocationLog) {
        if (StrUtil.isNotBlank(tlInspectionLocationLog.getAreaId())) {
            tlInspectionLocationLog.setAreaIds(StrUtil.split(tlInspectionLocationLog.getAreaId(), ','));
            tlInspectionLocationLog.setAreaId("");
        }
        List<TlInspectionLocationLog> list = tlInspectionLocationLogService.selectTlInspectionLocationLogTrailList(tlInspectionLocationLog);
        return AjaxResult.success(list);
    }

    /**
     * 导出巡检记录管理列表
     */
    @PreAuthorize("@ss.hasPermi('qdtl:log:export')")
    @Log(title = "巡检记录管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TlInspectionLocationLog tlInspectionLocationLog) {
        if (StrUtil.isNotBlank(tlInspectionLocationLog.getAreaId())) {
            tlInspectionLocationLog.setAreaIds(StrUtil.split(tlInspectionLocationLog.getAreaId(), ','));
            tlInspectionLocationLog.setAreaId("");
        }
        List<TlInspectionLocationLog> list = tlInspectionLocationLogService.selectTlInspectionLocationLogList(tlInspectionLocationLog);
        ExcelUtil<TlInspectionLocationLog> util = new ExcelUtil<TlInspectionLocationLog>(TlInspectionLocationLog.class);
        util.exportExcel(response, list, "巡检记录管理数据");
    }

    /**
     * 获取巡检记录管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('qdtl:log:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(tlInspectionLocationLogService.selectTlInspectionLocationLogById(id));
    }

    /**
     * 新增巡检记录管理
     */
    @PreAuthorize("@ss.hasPermi('qdtl:log:add')")
    @Log(title = "巡检记录管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TlInspectionLocationLog tlInspectionLocationLog) {
        return toAjax(tlInspectionLocationLogService.insertTlInspectionLocationLog(tlInspectionLocationLog));
    }

    /**
     * 修改巡检记录管理
     */
    @PreAuthorize("@ss.hasPermi('qdtl:log:edit')")
    @Log(title = "巡检记录管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TlInspectionLocationLog tlInspectionLocationLog) {
        return toAjax(tlInspectionLocationLogService.updateTlInspectionLocationLog(tlInspectionLocationLog));
    }

    /**
     * 删除巡检记录管理
     */
    @PreAuthorize("@ss.hasPermi('qdtl:log:remove')")
    @Log(title = "巡检记录管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tlInspectionLocationLogService.deleteTlInspectionLocationLogByIds(ids));
    }
}
